test/jtreg-ext/requires/VMProps.java
changeset 48880 ee49ac008730
parent 48155 551de50b4ff7
child 48957 af49718d8cf2
--- a/test/jtreg-ext/requires/VMProps.java	Wed Feb 07 10:25:10 2018 -0800
+++ b/test/jtreg-ext/requires/VMProps.java	Wed Feb 07 16:16:50 2018 +0100
@@ -352,9 +352,11 @@
      * @return true if docker is supported in a given environment
      */
     protected String dockerSupport() {
-        // currently docker testing is only supported for Linux-x64
-        if (! ( Platform.isLinux() && Platform.isX64() ) )
+        // currently docker testing is only supported for Linux-x64 and Linux-ppc64le
+        String arch = System.getProperty("os.arch");
+        if (! (Platform.isLinux() && (Platform.isX64() || arch.equals("ppc64le")))) {
             return "false";
+        }
 
         boolean isSupported;
         try {